Learn R Programming

smatr (version 3.5-1)

makeLogMinor: Generate spacing for minor tick marks on a plot with log-scaled axes

Description

Generates a sequence of numbers providing minor tick marks on log scaled axes.

A vector is created according to the following algorithm. For each pair of adjacent values (x1, x2) in major, the function adds the values (x1, 2*x1, 3*x1, ..., x2) to the vector of return values.

This is useful for generating spacing of minor tick-values on log-transformed axes.

Usage

makeLogMinor(major)

Value

vector of minor tick spacings approrpaite for log 10 scaled axis with major ticks given by 'major'

Arguments

major

a vector of values giving major tick marks.

Examples

Run this code
if (FALSE) {
#Sequence suitable for log base 10 labels
makeLogMinor(seqLog(1E-5, 1E5))
}

Run the code above in your browser using DataLab