This function allows the estimation of measurement error variance, given a
set of repeated measures on different subjects. Measurement error variance
is estimated separately for each subject, then averaged across subjects.
This provides terms that can be used to correct for measurement error in
allometric analyses.
Any number of variables can be specified in the data matrix for measurement
error calculation. If more than one variable is specified, the covariance of
measurement error is estimated from the repeated measures as well as the
variance.
As well as the estimated measurement error variance, a data matrix is
returned which contains the averages of the repeated measures for each
subject.