Learn R Programming

smatr (version 3.4-8)

multcompmatrix: Multiple comparisons graphical matrix

Description

Print a matrix of pair-wise comparisons based on an 'sma' fit.

Usage

multcompmatrix(smfit, sort = TRUE)

Value

Invisibly returns the (character) matrix.

Arguments

smfit

An object of class 'sma', fit with sma.

sort

Logical. Specifies whether or not to sort groups from smallest to largest value based on the parameter of interest (slope, elevation or mean fitted value).

Author

Remko Duursma and Daniel Falster.

Details

A matrix of comparisons is drawn, based on the P values of the pair-wise tests between levels of the grouping variable. An 'X' indicates P < 0.05, 'o' indicates 0.05 < P < 0.1.

See Also

sma

Examples

Run this code

# Print the matrix of comparisons:
data(leaflife)
sm1 <- sma(lma ~ longev + site, data=leaflife, multcomp=TRUE)
multcompmatrix(sm1)

# Write the matrix to a file like this:
if (FALSE) {
capture.output(multcompmatrix(sm1), file="sm1matrix.txt")
}

Run the code above in your browser using DataLab