Learn R Programming

smatr (version 3.5-1)

print.sma: Print an object of class 'sma'.

Description

Prints the coefficients and the results of the various hypothesis tests of an sma object.

Usage

# S3 method for sma
print(x, ..., coefbygroup = FALSE)

Arguments

x

Object of class 'sma'.

...

Further arguments ignored.

coefbygroup

Whether or not to print the coefficients by group.

Author

R.A. Duursma, D. Falster, D.I. Warton

See Also

sma