Learn R Programming

smatr (version 3.5-1)

seqLog: Sequence Generation

Description

Generate multiplicative sequences, or series.

Usage

seqLog(from, to, base = 10)

Value

vector from lo to hi with multiplication steps of incr. Used for making ticks to a log-scaled axis

Arguments

from, to

the starting and (maximal) end value of a sequence.

base

multiplication value.

Details

Starting at from, seq multiplies successively by base until the maximal value is reached. This is useful for generating tick-spacing on log-transformed axes.

Examples

Run this code
if (FALSE) {
#Sequence suitable for log base 10 labels
seqLog(1E-5, 1E5)

#Sequence suitable for log base 2 labels
seqLog(2, 128,base=2)
}

Run the code above in your browser using DataLab