Tests if the line relating y to x has a slope equal to test.value (which has
a default value of 1). The line can be a linear regression line, major axis
or standardised major axis (as selected using the input argument choice).
The test is carried out by testing for correlation between residual and
fitted values, as described in Warton et al (in review).
A confidence interval for the slope is also returned, which is the primary
confidence interval found by inverting the one-sample test statistic.
If measurement error is present, it can be corrected for through use of the
input argument V, which makes adjustments to the estimated sample variances
and covariances then proceeds with the same method of inference. Note,
however, that this method is only approximate (see Warton et al in review
for more details).
The test assumes the following:
y and x are linearly
related
residuals independently follow a normal distribution with
equal variance at all points along the line
The assumptions can be visually checked by plotting residual scores against
fitted axis scores, and by constructing a Q-Q plot of residuals against a
normal distribution, available using the plot.sma function.
Setting robust=TRUE fits lines using Huber's M estimation, and
modifies the test statistic as proposed in Taskinen & Warton (in review).