coef.sma: Extract coefficients from a 'sma' or 'ma' fit
Description
Extracts elevation and slope of a standardized major axis (sma) or major
axis (ma) fit, for each of the groups if the fit was by group.
Usage
# S3 method for sma
coef(object, ...)
Value
A dataframe with the slope(s) and elevation(s), and their confidence
intervals. If the fit was by multiple groups, fits by all groups are
returned.
Arguments
- object
Object of class 'sma'.
- ...
Further arguments ignored.