get_coef: Extract a fitted coefficient for one level of the grouping variable
Description
Extract a fitted coefficient for one level of the grouping variable
Usage
get_coef(obj, group_level, coef_type)
Value
A single numeric coefficient.
Arguments
- obj
An object of class sma.
- group_level
Character string naming the group level.
- coef_type
"a" for the intercept (elevation) or "B" for
the slope.