Generates a sequence of numbers providing minor tick marks on log scaled
axes.
A vector is created according to the following algorithm. For each pair of
adjacent values (x1, x2) in major, the function adds the values (x1,
2*x1, 3*x1, ..., x2) to the vector of return values.
This is useful for generating spacing of minor tick-values on
log-transformed axes.