Prints the coefficients and the results of the various hypothesis tests of
an sma object.
# S3 method for class 'sma'
print(x, ..., coefbygroup = FALSE)
Arguments
- x
Object of class 'sma'.
- ...
Further arguments ignored.
- coefbygroup
Whether or not to print the coefficients by group.
Author
R.A. Duursma, D. Falster, D.I. Warton